@@ -245,7 +245,7 @@ update_navigation_buttons (GisAssistant *assistant)
       gtk_widget_show (priv->forward);
 
       is_first_page = (page_priv->link->prev == NULL);
-      gtk_widget_set_sensitive (priv->back, !is_first_page);
+      gtk_widget_set_visible (priv->back, !is_first_page);
 
       can_go_forward = gis_page_get_complete (page);
       gtk_widget_set_sensitive (priv->forward, can_go_forward);
@@ -392,7 +392,7 @@ gis_assistant_locale_changed (GisAssistant *assistant)
   GList *l;
 
   gtk_button_set_label (GTK_BUTTON (priv->forward), _("_Next"));
-  gtk_button_set_label (GTK_BUTTON (priv->back), _("_Back"));
+  gtk_button_set_label (GTK_BUTTON (priv->back), _("_Previous"));
   gtk_button_set_label (GTK_BUTTON (priv->cancel), _("_Cancel"));
 
   for (l = priv->pages; l != NULL; l = l->next)
