@@ -26,6 +26,7 @@
 #include "gnome-initial-setup.h"
 
 #include <stdlib.h>
+#include <locale.h>
 
 #include "gis-assistant-gtk.h"
 #include "gis-assistant-gd.h"
@@ -76,9 +77,22 @@ struct _GisDriverPrivate {
   ActUser *user_account;
   const gchar *user_password;
 
+  gchar *lang_id;
+
   GisDriverMode mode;
 };
 
+static void
+gis_driver_finalize (GObject *object)
+{
+  GisDriver *driver = GIS_DRIVER (object);
+  GisDriverPrivate *priv = driver->priv;
+
+  g_free (priv->lang_id);
+
+  G_OBJECT_CLASS (gis_driver_parent_class)->finalize (object);
+}
+
 static void
 title_changed_cb (GisAssistant *assistant,
                   GParamSpec   *gparam,
@@ -121,6 +135,21 @@ gis_driver_get_assistant (GisDriver *driver)
   return priv->assistant;
 }
 
+void
+gis_driver_set_user_language (GisDriver *driver, const gchar *lang_id)
+{
+  GisDriverPrivate *priv = driver->priv;
+  g_free (priv->lang_id);
+  priv->lang_id = g_strdup (lang_id);
+}
+
+const gchar *
+gis_driver_get_user_language (GisDriver *driver)
+{
+  GisDriverPrivate *priv = driver->priv;
+  return priv->lang_id;
+}
+
 void
 gis_driver_set_user_permissions (GisDriver   *driver,
                                  ActUser     *user,
@@ -231,6 +260,16 @@ gis_driver_activate (GApplication *app)
   gtk_window_present (GTK_WINDOW (priv->main_window));
 }
 
+static void
+window_realize_cb (GtkWidget *widget, gpointer user_data)
+{
+  GisDriverPrivate *priv = GIS_DRIVER (user_data)->priv;
+  GdkWindow *window;
+  window = gtk_widget_get_window (GTK_WIDGET (priv->main_window));
+  /* disable WM functions except move */
+  gdk_window_set_functions (window, GDK_FUNC_MOVE);
+}
+
 static void
 gis_driver_startup (GApplication *app)
 {
@@ -244,16 +283,22 @@ gis_driver_startup (GApplication *app)
                                     "type", GTK_WINDOW_TOPLEVEL,
                                     "border-width", 12,
                                     "icon-name", "preferences-system",
-                                    "deletable", FALSE,
                                     "resizable", FALSE,
                                     "window-position", GTK_WIN_POS_CENTER_ALWAYS,
                                     NULL);
 
+  g_signal_connect (priv->main_window,
+                    "realize",
+                    G_CALLBACK (window_realize_cb),
+                    (gpointer)app);
+
   priv->assistant = g_object_new (get_assistant_type (), NULL);
   gtk_container_add (GTK_CONTAINER (priv->main_window), GTK_WIDGET (priv->assistant));
 
   gtk_widget_show (GTK_WIDGET (priv->assistant));
 
+  gis_driver_set_user_language (driver, setlocale (LC_MESSAGES, NULL));
+
   prepare_main_window (driver);
   rebuild_pages (driver);
 }
@@ -274,6 +319,7 @@ gis_driver_class_init (GisDriverClass *klass)
 
   gobject_class->get_property = gis_driver_get_property;
   gobject_class->set_property = gis_driver_set_property;
+  gobject_class->finalize = gis_driver_finalize;
   application_class->startup = gis_driver_startup;
   application_class->activate = gis_driver_activate;
   klass->locale_changed = gis_driver_real_locale_changed;
