@@ -30,6 +30,7 @@
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <gtk/gtk.h>
+#include <polkit/polkit.h>
 
 #include "gis-keyboard-page.h"
 #include "keyboard-resources.h"
@@ -73,7 +74,9 @@ struct _GisKeyboardPagePrivate {
         GtkWidget *show_layout;
         GtkWidget *input_scrolledwindow;
         guint n_input_rows;
-        guint gkbd_pid;
+        GPid gkbd_pid;
+        GPermission *permission;
+
 
         GSettings *input_settings;
         GnomeXkbInfo *xkb_info;
@@ -96,6 +99,7 @@ gis_keyboard_page_finalize (GObject *object)
         g_cancellable_cancel (priv->cancellable);
         g_clear_object (&priv->cancellable);
 
+        g_clear_object (&priv->permission);
         g_clear_object (&priv->localed);
         g_clear_object (&priv->input_settings);
         g_clear_object (&priv->xkb_info);
@@ -148,18 +152,16 @@ gis_keyboard_page_constructed (GObject *object)
                                   (GAsyncReadyCallback) localed_proxy_ready,
                                   self);
 
+        /* If we're in new user mode then we're manipulating system settings */
+        if (gis_driver_get_mode (GIS_PAGE (self)->driver) == GIS_DRIVER_MODE_NEW_USER)
+                priv->permission = polkit_permission_new_sync ("org.freedesktop.locale1.set-keyboard", NULL, NULL, NULL);
+
         g_signal_connect (assistant, "next-page", G_CALLBACK (next_page_cb), self);
 
         gis_page_set_complete (GIS_PAGE (self), TRUE);
         gtk_widget_show (GTK_WIDGET (self));
 }
 
-static const char *
-gis_keyboard_page_get_help_uri (GisPage *page)
-{
-        return "help:gnome-help/prefs-language";
-}
-
 static void
 gis_keyboard_page_locale_changed (GisPage *page)
 {
@@ -601,12 +603,53 @@ set_input_settings (GisKeyboardPage *self)
         g_variant_unref (old_sources);
 }
 
+
 static void set_localed_input (GisKeyboardPage *self);
 
+static void
+change_locale_permission_acquired (GObject      *source,
+                                   GAsyncResult *res,
+                                   gpointer      data)
+{
+  GisKeyboardPagePrivate *priv;
+  GError *error = NULL;
+  gboolean allowed;
+
+  priv = GIS_KEYBOARD_PAGE (data)->priv;
+
+  allowed = g_permission_acquire_finish (priv->permission, res, &error);
+  if (error) {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Failed to acquire permission: %s\n", error->message);
+      g_error_free (error);
+      return;
+  }
+
+  if (allowed)
+    set_localed_input (GIS_KEYBOARD_PAGE (data));
+}
+
+
 static void
 update_input (GisKeyboardPage *self)
 {
-        set_input_settings (self);
+  GisKeyboardPagePrivate *priv;
+
+  priv = self->priv;
+
+  set_input_settings (self);
+
+  if (gis_driver_get_mode (GIS_PAGE (self)->driver) == GIS_DRIVER_MODE_NEW_USER) {
+      if (g_permission_get_allowed (priv->permission)) {
+          set_localed_input (self);
+      }
+      else if (g_permission_get_can_acquire (priv->permission)) {
+          g_permission_acquire_async (priv->permission,
+                                      NULL,
+                                      change_locale_permission_acquired,
+                                      self);
+      }
+  }
 }
 
 static gboolean
@@ -632,7 +675,6 @@ static void
 input_response (GtkWidget *chooser, gint response_id, gpointer data)
 {
 	GisKeyboardPage *self = data;
-        GisKeyboardPagePrivate *priv = self->priv;
         gchar *type;
         gchar *id;
         gchar *name;
@@ -868,7 +910,6 @@ show_selected_layout (GisKeyboardPage *self)
 static void
 add_default_input_source_for_locale (GisKeyboardPage *self)
 {
-        GisKeyboardPagePrivate *priv = self->priv;
         const gchar *locale;
         const gchar *type;
         const gchar *id;
