@@ -111,27 +111,24 @@ user_loaded (GObject    *object,
 }
 
 static void
-language_changed (CcLanguageChooser  *chooser,
-                  GParamSpec         *pspec,
-                  GisLanguagePage    *page)
+set_language (GisLanguagePage *page)
 {
   GisLanguagePagePrivate *priv = page->priv;
+  GisDriver *driver = GIS_PAGE (page)->driver;
   ActUser *user;
-  GisDriver *driver;
 
-  priv->new_locale_id = cc_language_chooser_get_language (chooser);
-  driver = GIS_PAGE (page)->driver;
+  priv->new_locale_id = cc_language_chooser_get_language (CC_LANGUAGE_CHOOSER (priv->language_chooser));
 
-  setlocale (LC_MESSAGES, priv->new_locale_id);
-  gis_driver_locale_changed (driver);
-
-  if (gis_driver_get_mode (driver) == GIS_DRIVER_MODE_NEW_USER &&
-      g_permission_get_can_acquire (priv->permission)) {
-
-      g_permission_acquire_async (priv->permission,
-                                  NULL,
-                                  change_locale_permission_acquired,
-                                  page);
+  if (gis_driver_get_mode (driver) == GIS_DRIVER_MODE_NEW_USER) {
+      if (g_permission_get_allowed (priv->permission)) {
+          set_localed_locale (page);
+      }
+      else if (g_permission_get_can_acquire (priv->permission)) {
+          g_permission_acquire_async (priv->permission,
+                                      NULL,
+                                      change_locale_permission_acquired,
+                                      page);
+      }
   }
   user = act_user_manager_get_user (act_user_manager_get_default (),
                                     g_get_user_name ());
@@ -146,6 +143,19 @@ language_changed (CcLanguageChooser  *chooser,
   gis_driver_set_user_language (driver, priv->new_locale_id);
 }
 
+static void
+language_changed (CcLanguageChooser  *chooser,
+                  GParamSpec         *pspec,
+                  GisLanguagePage    *page)
+{
+  GisLanguagePagePrivate *priv = page->priv;
+  GisDriver *driver = GIS_PAGE (page)->driver;
+
+  set_language (page);
+  setlocale (LC_MESSAGES, priv->new_locale_id);
+  gis_driver_locale_changed (driver);
+}
+
 static void
 localed_proxy_ready (GObject      *source,
                      GAsyncResult *res,
@@ -205,6 +215,8 @@ gis_language_page_constructed (GObject *object)
       g_object_unref (bus);
   }
 
+  set_language (page);
+
   gis_page_set_complete (GIS_PAGE (page), TRUE);
   gtk_widget_show (GTK_WIDGET (page));
 }
